Uses of Package org.openqa.selenium.server.browserlaunchers.locators (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Package
org.openqa.selenium.server.browserlaunchers.locators

Packages that use org.openqa.selenium.server.browserlaunchers.locators
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.
org.openqa.selenium.server.browserlaunchers.locators |

Classes in org.openqa.selenium.server.browserlaunchers.locators used by org.openqa.selenium.server.browserlaunchers
BrowserLocator Discovers a valid browser installation on local system.

Classes in org.openqa.selenium.server.browserlaunchers.locators used by org.openqa.selenium.server.browserlaunchers.locators
BrowserLocator Discovers a valid browser installation on local system.
FirefoxLocator Discovers a valid Firefox installation on local system.
SingleBrowserLocator Discovers a valid browser installation on local system.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.